@@ -19,10 +19,7 @@ MooseX::Types::OpenHandle - Type for opened file handle
 
 =head1 DESCRIPTION
 
-This module provides Moose type which represents special cached file handle -
-underscore (C<_>) - which is used for C<stat> tests.
-
-opened file handle (glob
+This module provides L<Moose> type which represents opened file handle (glob
 reference or object).
 
 =cut
@@ -32,7 +29,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 use Moose::Util::TypeConstraints;
 
@@ -64,11 +61,11 @@ L<Moose::Util::TypeConstraints>, L<File::Stat::Moose>.
 
 =head1 AUTHOR
 
-Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
+Piotr Roszatycki <dexter@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2007, 2008 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
+Copyright (C) 2007, 2008, 2009 by Piotr Roszatycki <dexter@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
